3DGAN
=====

This section covers the CERN use case that utilizes the `torch-lightning` framework 
for training and evaluation. Following you can find instructions to execute CERN use 
case and its integral scripts:

itwinai x 3DGAN
---------------

.. include:: ../../use-cases/3dgan/README.md
   :parser: myst_parser.sphinx_
   :start-line: 2


interLink x 3DGAN
-----------------

The CERN use case also has an integration with the ``interLink`` tool. You can find
the relevant files in the 
`interLink folder on Github <https://github.com/interTwin-eu/itwinai/tree/main/use-cases/3dgan/interLink>`_.
You can also look at the README for more information:


.. include:: ../../use-cases/3dgan/interLink/README.md
   :parser: myst_parser.sphinx_
   :start-line: 0
